@@ -19,13 +19,14 @@
 
 
 import re
+import urllib.parse
 from dataclasses import dataclass
 from typing import Optional
 
 import daiquiri
 import gitlab
 import typer
-from gitlab.v4.objects import DeployKey, Project, ProjectPipelineSchedule, VISIBILITY_PUBLIC
+from gitlab.v4.objects import VISIBILITY_PUBLIC, DeployKey, Project, ProjectPipelineSchedule, ProjectTrigger
 
 from .. import constants, loaders, ssh
 
@@ -35,6 +36,8 @@ fetchers_group_name = "dbnomics-fetchers"
 source_data_group_name = "dbnomics-source-data"
 json_data_group_name = "dbnomics-json-data"
 fetcher_pipeline_project_name = "dbnomics/dbnomics-fetcher-pipeline"
+data_model_project_name = "dbnomics/dbnomics-data-model"
+solr_project_name = "dbnomics/dbnomics-solr"
 CI_JOBS_KEY = "CI jobs"
 JOB = "JOB"
 RUN_FETCHER = "Run fetcher"
@@ -93,12 +96,31 @@ def configure_command(
     if debug_gitlab:
         gl.enable_debug()
 
+    # Get data model and solr projects.
+    data_model_project = gl.projects.get(data_model_project_name)
+    solr_project = gl.projects.get(solr_project_name)
+
+    # Get data model project trigger.
+    data_model_triggers = data_model_project.triggers.list()
+    assert len(data_model_triggers) == 1, data_model_triggers
+    data_model_trigger = data_model_triggers[0]
+
+    # Get solr project trigger.
+    solr_triggers = solr_project.triggers.list()
+    assert len(solr_triggers) == 1, solr_triggers
+    solr_trigger = solr_triggers[0]
+
     ctx = Context(
         dry_run=dry_run,
+        gitlab_url=gitlab_url,
         gl=gl,
         provider_slug=provider_slug,
         schedule_cron=schedule_cron,
         schedule_cron_timezone=schedule_cron_timezone,
+        solr_project=solr_project,
+        data_model_project=data_model_project,
+        solr_trigger=solr_trigger,
+        data_model_trigger=data_model_trigger,
     )
 
     fetcher_project = gl.projects.get(f"{fetchers_group_name}/{provider_slug}-fetcher")
@@ -124,21 +146,30 @@ def configure_command(
     # Remove legacy stuff.
     delete_triggers(fetcher_project, ctx)
     delete_webhooks(source_data_project, ctx)
-    delete_webhooks(json_data_project, ctx)
 
     # Switch to new CI conf.
     ensure_new_ci_conf(fetcher_project, ctx)
     ensure_pipeline_schedule(fetcher_project, ctx)
     ensure_ssh_key_pair(fetcher_project, source_data_project, json_data_project, ctx)
+    ensure_json_data_webhooks(json_data_project, ctx)
 
 
 @dataclass
 class Context:
+    gitlab_url: str
     dry_run: bool
     gl: gitlab.Gitlab
     provider_slug: str
     schedule_cron: Optional[str]
     schedule_cron_timezone: Optional[str]
+    solr_project: Project
+    data_model_project: Project
+    solr_trigger: ProjectTrigger
+    data_model_trigger: ProjectTrigger
+
+    @property
+    def gitlab_api_base_url(self):
+        return f"{self.gitlab_url}/api/v4"
 
 
 def get_deploy_key_title(ctx: Context):
@@ -275,6 +306,30 @@ def ensure_new_ci_conf(project: Project, ctx: Context):
             logger.info(".gitlab-ci.yml file %r updated in %r", gitlab_ci_file, project)
 
 
+def ensure_json_data_webhooks(project: Project, ctx: Context):
+    if not ctx.dry_run:
+        solr_trigger_url = (
+            f"{ctx.gitlab_api_base_url}/projects/{ctx.solr_project.id}/ref/master/trigger/pipeline?"
+            + urllib.parse.urlencode({"token": ctx.solr_trigger.token, "variables[PROVIDER_SLUG]": ctx.provider_slug})
+        )
+        validate_trigger_url = (
+            f"{ctx.gitlab_api_base_url}/projects/{ctx.data_model_project.id}/ref/master/trigger/pipeline?"
+            + urllib.parse.urlencode(
+                {"token": ctx.data_model_trigger.token, "variables[PROVIDER_SLUG]": ctx.provider_slug}
+            )
+        )
+        hook_urls = [hook.url for hook in project.hooks.list(as_list=False)]
+        if solr_trigger_url not in hook_urls:
+            create_push_webhook(project, ctx, url=solr_trigger_url)
+        if validate_trigger_url not in hook_urls:
+            create_push_webhook(project, ctx, url=validate_trigger_url)
+
+
+def create_push_webhook(project: Project, ctx: Context, *, branch_filter: str = "master", url: str):
+    hook = project.hooks.create({"url": url, "push_events": 1, "push_events_branch_filter": branch_filter})
+    logger.info("%r created for %r", hook, project)
+
+
 def delete_triggers(project: Project, ctx: Context):
     logger.info("Deleting triggers of %r...", project)
     for trigger in project.triggers.list(as_list=False):
