@@ -20,3 +20,5 @@
 
 FETCHERS_YML_URL = "https://git.nomics.world/dbnomics-fetchers/management/raw/master/fetchers.yml"
 GITLAB_URL = "https://git.nomics.world"
+SCHEDULE_CRON = "0 1 * * *"
+SCHEDULE_CRON_TIMEZONE = "UTC"
